@@ -15,7 +15,7 @@ def write(file,bin_to_add):
     bin_to_add+="0000000"
     for i in [bin_to_add[i:i+8] for i in range(0, len(bin_to_add)-7, 8)]:
         bin_array.append(int(i,2))
-    with open(file,'wb') as f:
+    with open(file,'wb+') as f:
         bin_array.tofile(f)
 def append(file,bin_to_add):
     write(file, read(file) + bin_to_add)
